1.11. What’s next? — CubicWeb 3.10.1

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Tutorials »
- 1. Building a simple blog »

# 1.11. What’s next?

In this chapter, we have seen have you can, right after the installation of CubicWeb, build a web application in five minutes by defining a data model. Everything is there already: views, templates, permissions, etc.

The next step is to change the design and learn about the many features available to customize and extend your application: RSS channels (XML and RSS views), events (Hooks and Operations), support of sources such as Google App Engine (CubicWeb in Google AppEngine), etc.

You will find more tutorials and howtos in the blog published on the CubicWeb.org website.

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Tutorials »
- 1. Building a simple blog »